"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEntityAttributes = void 0;
const graphql_1 = require("graphql");
const getTopFieldName_1 = require("./getTopFieldName");
const utils_1 = require("../../../../../common/utils");
const getAttributeNames_1 = require("./getAttributeNames");
const getEntityName_1 = require("./getEntityName");
const getTypeFields_1 = require("./getTypeFields");
const isAnyLeafType_1 = require("./isAnyLeafType");
function getEntityAttributes(documentNode, schema) {
    // e.g. "petList"
    const queryFieldName = getTopFieldName_1.getTopFieldName(documentNode);
    // e.g. "PetDTO"
    const entityName = getEntityName_1.getEntityName(queryFieldName, schema);
    const typeFields = getTypeFields_1.getTypeFields(entityName, schema);
    return Object.keys(typeFields)
        .filter(fieldKey => {
        // Do not include id attribute
        return typeFields[fieldKey].name !== 'id'; // TODO determine id field from schema
    })
        .map(fieldKey => {
        const field = typeFields[fieldKey];
        const fieldType = (field.type instanceof graphql_1.GraphQLList || field.type instanceof graphql_1.GraphQLNonNull)
            ? field.type.ofType.name
            : field.type.name;
        return {
            name: field.name,
            displayName: utils_1.capitalizeFirst(utils_1.splitByCapitalLetter(field.name)),
            isRelationField: !(isAnyLeafType_1.isAnyLeafType(field.type)),
            type: fieldType,
            nestedAttributes: isAnyLeafType_1.isAnyLeafType(field.type)
                ? undefined
                : getAttributeNames_1.getAttributeNames(fieldType, schema),
            idField: 'id' // TODO Get id field name from schema
        };
    });
}
exports.getEntityAttributes = getEntityAttributes;
//# sourceMappingURL=getEntityAttributes.js.map