"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_tag_1 = __importDefault(require("graphql-tag"));
const chai_1 = require("chai");
const getEntityAttributes_1 = require("./getEntityAttributes");
const test_commons_1 = require("../../../../../test/test-commons");
describe('entity list template model stage', () => __awaiter(void 0, void 0, void 0, function* () {
    let schema;
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        schema = yield test_commons_1.getMockSchema();
    }));
    it('derives a list of entity attributes', () => {
        const attributes = getEntityAttributes_1.getEntityAttributes(QUERY_NODE, schema);
        chai_1.expect(attributes.sort()).to.deep.equal(RESULT.sort());
    });
    it('relation field is marked as such', () => {
        const attributes = getEntityAttributes_1.getEntityAttributes(QUERY_NODE, schema);
        const ownerAttr = attributes.find(attr => attr.name === 'owner');
        chai_1.expect(ownerAttr === null || ownerAttr === void 0 ? void 0 : ownerAttr.isRelationField).to.eq(true);
    });
    it('relation field has entity name', () => {
        const attributes = getEntityAttributes_1.getEntityAttributes(QUERY_NODE, schema);
        const ownerAttr = attributes.find(attr => attr.name === 'owner');
        chai_1.expect(ownerAttr === null || ownerAttr === void 0 ? void 0 : ownerAttr.type).to.eq('OwnerDTO');
    });
}));
const QUERY_NODE = graphql_tag_1.default(`
    query Get_Pet_List {
        petList {
            id
            identificationNumber
            owner {
                firstName
                lastName
            }
            type {
                id
            }
        }
    }
`);
const RESULT = [
    {
        allNestedAttributes: undefined,
        displayName: "Birth Date",
        isRelationField: false,
        name: "birthDate",
        type: "Date",
    },
    {
        allNestedAttributes: undefined,
        displayName: "Id",
        isRelationField: false,
        name: "id",
        type: "BigInteger",
    },
    {
        allNestedAttributes: undefined,
        displayName: "Identification Number",
        isRelationField: false,
        name: "identificationNumber",
        type: "String",
    },
    {
        allNestedAttributes: [
            "address",
            "city",
            "email",
            "firstName",
            "id",
            "lastName",
            "telephone",
        ],
        displayName: "Owner",
        isRelationField: true,
        name: "owner",
        type: "OwnerDTO",
    },
    {
        "allNestedAttributes": [
            "id",
            "name"
        ],
        displayName: "Type",
        isRelationField: true,
        name: "type",
        type: "PetTypeDTO",
    },
];
//# sourceMappingURL=getEntityAttributes.test.js.map