"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addI18nMessagesEn = exports.addScreenI18nKeyEn = exports.writeAmplicodeComponent = void 0;
const path_1 = __importDefault(require("path"));
const utils_1 = require("../../../../../common/utils");
const addMvpAppMenu_1 = require("./addMvpAppMenu");
const previews_registration_1 = require("../previews-registration");
function writeAmplicodeComponent(templateModel, gen, srcPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const { relDirShift, componentName, route, shouldAddToMenu } = templateModel;
        gen.log(`Generating to ${gen.destinationPath()}`);
        gen.fs.copyTpl(srcPath, gen.destinationPath(componentName + '.tsx'), templateModel);
        if (shouldAddToMenu) {
            addMvpAppMenu_1.addMvpAppMenu({
                gen,
                dirShift: relDirShift,
                route,
                componentName
            });
        }
        // TODO Previews
        // addComponentPreviews(gen, relDirShift, className, className, true, {
        //   paginationConfig: {},
        //   onPagingChange: () => {}
        // });
        addScreenI18nKeyEn(componentName, relDirShift, gen);
        previews_registration_1.addComponentPreviews(gen, relDirShift, componentName, componentName);
    });
}
exports.writeAmplicodeComponent = writeAmplicodeComponent;
function addScreenI18nKeyEn(className, dirShift, gen, componentType = "screen") {
    const existingMessagesPath = path_1.default.join(dirShift, 'core', 'i18n', 'en.json');
    const existingMessages = gen.fs.readJSON(existingMessagesPath);
    if (existingMessages == null) {
        throw new Error('i18n messages not found');
    }
    const screenNameKey = `${componentType}.${className}`;
    if (Object.keys(existingMessages).includes(screenNameKey)) {
        return;
    }
    const screenCaption = utils_1.splitByCapitalLetter(utils_1.capitalizeFirst(className));
    const mergedMessages = Object.assign(Object.assign({}, existingMessages), { [screenNameKey]: screenCaption });
    gen.fs.writeJSON(existingMessagesPath, mergedMessages);
}
exports.addScreenI18nKeyEn = addScreenI18nKeyEn;
function addI18nMessagesEn(dirShift, gen, messages) {
    const existingMessagesPath = path_1.default.join(dirShift, 'core', 'i18n', 'en.json');
    const existingMessages = gen.fs.readJSON(existingMessagesPath);
    if (existingMessages == null) {
        throw new Error('i18n messages not found');
    }
    const existingKeys = Object.keys(existingMessages);
    const messagesKeys = Object.keys(messages);
    const keysToMerge = messagesKeys.filter((messageKey) => {
        const isMessageKeyExist = existingKeys.includes(messageKey);
        if (isMessageKeyExist) {
            gen.log(`message key '${messageKey}' already exists and will not be merged`);
        }
        return !isMessageKeyExist;
    });
    if (keysToMerge.length === 0) {
        gen.log(`messages don't have any keys to merge`);
        return;
    }
    const messagesToMerge = keysToMerge.reduce((msgs, key) => {
        return Object.assign(Object.assign({}, msgs), { [key]: messages[key] });
    }, {});
    const mergedMessages = Object.assign(Object.assign({}, existingMessages), messagesToMerge);
    gen.fs.writeJSON(existingMessagesPath, mergedMessages);
}
exports.addI18nMessagesEn = addI18nMessagesEn;
//# sourceMappingURL=mvp.js.map