"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseParamType = exports.createMethodParamsType = exports.collectMethods = void 0;
const typescript_1 = __importDefault(require("typescript"));
const import_utils_1 = require("../import-utils");
const constants_1 = require("../../../../../../common/constants");
const ts_shorthands_1 = require("../../../../../../common/ts-shorthands");
function collectMethods(methods) {
    const methodWithOverloadsList = [];
    methods.forEach(m => {
        const mwo = methodWithOverloadsList.find(value => value.methodName == m.name);
        if (mwo) {
            //method with such name already exist - m is overload, add to as overload method
            mwo.methods.push(m);
        }
        else {
            //no methods with such name - create new entry
            methodWithOverloadsList.push({ methodName: m.name, methods: [m] });
        }
    });
    return methodWithOverloadsList;
}
exports.collectMethods = collectMethods;
function createMethodParamsType(overloadMethods, namePrefix, ctx) {
    const typeNodes = [];
    const importInfos = [];
    overloadMethods.forEach(method => {
        const members = [];
        method.params.forEach(p => {
            const { typeNode, importInfo } = parseParamType(p, ctx);
            if (importInfo)
                importInfos.push(importInfo);
            members.push(typescript_1.default.createPropertySignature(undefined, p.name, undefined, typeNode, undefined));
        });
        typeNodes.push(typescript_1.default.createTypeLiteralNode(members));
    });
    const name = methodParamsTypeName(overloadMethods[0].name, namePrefix);
    const paramTypeNode = typescript_1.default.createTypeAliasDeclaration(undefined, [ts_shorthands_1.exportModifier()], name, undefined, typescript_1.default.createUnionTypeNode(typeNodes));
    return {
        paramTypeNode,
        importInfos,
        name
    };
}
exports.createMethodParamsType = createMethodParamsType;
function parseParamType(param, ctx) {
    const typeEnum = ctx.enumsMap.get(param.type);
    if (typeEnum) {
        return {
            typeNode: typescript_1.default.createTypeReferenceNode(typeEnum.name.text, undefined),
            importInfo: import_utils_1.enumImportInfo(typeEnum)
        };
    }
    const typeEntity = ctx.entitiesMap.get(param.type);
    if (typeEntity) {
        return {
            typeNode: typescript_1.default.createTypeReferenceNode(typeEntity.entity.className, undefined),
            importInfo: import_utils_1.entityImportInfo(typeEntity, constants_1.ENTITIES_DIR)
        };
    }
    let typeNode;
    switch (param.type) {
        case 'java.lang.Boolean':
            typeNode = typescript_1.default.createKeywordTypeNode(typescript_1.default.SyntaxKind.BooleanKeyword);
            break;
        case 'java.lang.Integer':
            typeNode = typescript_1.default.createKeywordTypeNode(typescript_1.default.SyntaxKind.NumberKeyword);
            break;
        case 'java.util.UUID':
        case 'java.lang.String':
            typeNode = typescript_1.default.createKeywordTypeNode(typescript_1.default.SyntaxKind.StringKeyword);
            break;
        default:
            typeNode = typescript_1.default.createKeywordTypeNode(typescript_1.default.SyntaxKind.AnyKeyword);
    }
    return { typeNode, importInfo: undefined };
}
exports.parseParamType = parseParamType;
function methodParamsTypeName(methodName, namePrefix) {
    return `${namePrefix}_${methodName}_params`;
}
//# sourceMappingURL=method-params-type.js.map