"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDisplayedAttributes = exports.isStringIdEntity = exports.createEntityTemplateModel = exports.ScreenType = void 0;
const cuba_model_utils_1 = require("../../../common/model/cuba-model-utils");
const template_model_1 = require("./template-model");
var ScreenType;
(function (ScreenType) {
    ScreenType["BROWSER"] = "browser";
    ScreenType["EDITOR"] = "editor";
})(ScreenType = exports.ScreenType || (exports.ScreenType = {}));
function createEntityTemplateModel(entity, projectModel) {
    return Object.assign(Object.assign({}, entity), { path: template_model_1.getEntityPath(entity, projectModel) });
}
exports.createEntityTemplateModel = createEntityTemplateModel;
/**
 *
 * @param projectModel
 * @param entity
 * @returns `true` if a given entity is a descendant of `BaseStringIdEntity`
 */
function isStringIdEntity(projectModel, entity) {
    if (entity.fqn === 'com.haulmont.cuba.core.entity.BaseStringIdEntity') {
        return true;
    }
    if (entity.parentPackage == null || entity.parentClassName == null) {
        return false;
    }
    const parentFqn = cuba_model_utils_1.composeParentFqn(entity.parentPackage, entity.parentClassName);
    const parentEntity = cuba_model_utils_1.findEntityByFqn(projectModel, parentFqn);
    if (parentEntity == null) {
        return false;
    }
    return isStringIdEntity(projectModel, parentEntity);
}
exports.isStringIdEntity = isStringIdEntity;
function getDisplayedAttributes(viewProperties, entity, projectModel, screenType) {
    return viewProperties.reduce((attrArr, prop) => {
        const attr = cuba_model_utils_1.collectAttributesFromHierarchy(entity, projectModel).find(ea => ea.name === prop.name);
        if (attr && isDisplayedAttribute(attr, screenType, entity)) {
            attrArr.push(attr);
        }
        return attrArr;
    }, []);
}
exports.getDisplayedAttributes = getDisplayedAttributes;
function isDisplayedAttribute(attr, screenType, entity) {
    var _a;
    if (screenType === ScreenType.BROWSER) {
        // Do not display many to many associations in browser
        if (attr.mappingType === 'ASSOCIATION' && attr.cardinality === "MANY_TO_MANY") {
            return false;
        }
        // Do not display one to many compositions in browser
        if (attr.mappingType === 'COMPOSITION' && attr.cardinality === 'ONE_TO_MANY') {
            return false;
        }
    }
    // Do not display one to many associations
    if (attr.mappingType === 'ASSOCIATION' && attr.cardinality === 'ONE_TO_MANY') {
        return false;
    }
    // Do not display byte arrays
    if (attr.mappingType === 'DATATYPE' && ((_a = attr.type) === null || _a === void 0 ? void 0 : _a.fqn) === 'byte[]') {
        return false;
    }
    // Do not display trait attributes
    if (attr.traitAttribute !== undefined) {
        return false;
    }
    // Do not display id attribute unless it is a String ID entity
    // TODO currently doesn't check for String ID entity
    // noinspection RedundantIfStatementJS
    if (attr.name === entity.idAttributeName) {
        return false;
    }
    return true;
}
//# sourceMappingURL=entity.js.map