"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveGraphQLEditorModel = exports.deriveEntityDetailsTemplateModel = void 0;
const graphql_1 = require("graphql");
const util_1 = require("../../../building-blocks/stages/template-model/pieces/util");
const graphql_tag_1 = __importDefault(require("graphql-tag"));
const ScreenTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/ScreenTemplateModel");
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const getEntityAttributes_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityAttributes");
const getEntityName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityName");
const getTopFieldName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getTopFieldName");
const deriveEntityDetailsTemplateModel = (options, answers, schema) => __awaiter(void 0, void 0, void 0, function* () {
    const { query: queryString, mutation: mutationString, idField = 'id', refetchQueryName } = answers;
    const queryNode = graphql_tag_1.default(queryString);
    const mutationNode = mutationString != null
        ? graphql_tag_1.default(mutationString)
        : undefined;
    return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, BaseTemplateModel_1.baseTemplateModel), util_1.templateUtilities), ScreenTemplateModel_1.deriveScreenTemplateModel(options, answers)), deriveGraphQLEditorModel(queryNode, idField, schema, mutationNode)), { 
        // TODO problem with $id: String = "", quotation marks get messed up
        queryString,
        mutationString,
        idField,
        refetchQueryName });
});
exports.deriveEntityDetailsTemplateModel = deriveEntityDetailsTemplateModel;
function deriveGraphQLEditorModel(queryNode, idField, schema, mutationNode) {
    if (schema == null) {
        throw new Error('Schema is required for this generator');
    }
    const queryName = getTopFieldName_1.getTopFieldName(queryNode);
    const entityName = getEntityName_1.getEntityName(queryName, schema);
    if (mutationNode == null) {
        const readOnlyAttributes = getEntityAttributes_1.getEntityAttributes(queryNode, schema);
        return {
            queryName,
            attributes: readOnlyAttributes,
            entityName
        };
    }
    const operationDefinition = mutationNode.definitions[0];
    if (!('variableDefinitions' in operationDefinition) || operationDefinition.variableDefinitions == null) {
        throw new Error('Variable definitions not found in mutation');
    }
    const inputVariableName = operationDefinition.variableDefinitions[0].variable.name.value;
    const inputType = operationDefinition.variableDefinitions[0].type;
    let inputTypeName;
    if ('name' in inputType) {
        inputTypeName = inputType.name.value;
    }
    if ('type' in inputType && 'name' in inputType.type) {
        inputTypeName = inputType.type.name.value;
    }
    if (inputTypeName == null) {
        throw new Error('Input type name not found');
    }
    const mutationName = getTopFieldName_1.getTopFieldName(mutationNode);
    const queryType = schema.getQueryType();
    if (queryType == null) {
        throw new Error('Query type not found');
    }
    const outputType = queryType.getFields()[queryName].type;
    if (!('name' in outputType)) {
        throw new Error('Output type name not found');
    }
    const typeMap = schema.getTypeMap();
    if (typeMap == null) {
        throw new Error('Type map not found');
    }
    const namedType = typeMap[inputTypeName];
    if (namedType instanceof graphql_1.GraphQLScalarType
        || namedType instanceof graphql_1.GraphQLUnionType
        || namedType instanceof graphql_1.GraphQLEnumType) {
        throw new Error('Unexpected type');
    }
    let hasStringScalars = false;
    let hasIntScalars = false;
    let hasFloatScalars = false;
    const hasIDScalars = false;
    let hasBooleanScalars = false;
    let hasEnumScalars = false;
    let hasCustomScalars = false;
    let hasRelationFields = false;
    // We take attributes from query, otherwise it won't be possible to pair the entity type from editor with entity type from list
    const attributes = getEntityAttributes_1.getEntityAttributes(queryNode, schema);
    // We need to take some info from mutation input and add it to `attributes`
    Object.values(namedType.getFields()).map((field) => {
        const attr = attributes.find(a => a.name === field.name);
        if (attr == null) {
            return;
        }
        switch (attr.type) {
            case 'Int':
                hasIntScalars = true;
                break;
            case 'Float':
                hasFloatScalars = true;
                break;
            case 'String':
                hasStringScalars = true;
                break;
            case 'ID':
                hasIntScalars = true;
                break;
            case 'Boolean':
                hasBooleanScalars = true;
                break;
            default:
                if (field.type instanceof graphql_1.GraphQLEnumType) {
                    attr.enumOptions = field.type.getValues();
                    hasEnumScalars = true;
                }
                else if (field.type instanceof graphql_1.GraphQLInputObjectType) {
                    attr.isRelationField = true;
                    hasRelationFields = true;
                }
                else if (field.type instanceof graphql_1.GraphQLScalarType) {
                    hasCustomScalars = true;
                }
        }
    });
    return {
        queryName,
        mutationName,
        attributes,
        entityName,
        hasStringScalars,
        hasIntScalars,
        hasFloatScalars,
        hasIDScalars,
        hasBooleanScalars,
        hasEnumScalars,
        hasCustomScalars,
        hasRelationFields,
        inputVariableName
    };
}
exports.deriveGraphQLEditorModel = deriveGraphQLEditorModel;
//# sourceMappingURL=template-model.js.map