"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const js_yaml_1 = __importDefault(require("js-yaml"));
const path_1 = __importDefault(require("path"));
const chai_1 = require("chai");
const assert_1 = __importDefault(require("assert"));
const commons_1 = require("../../commons");
const DEST_DIR = path_1.default.join(process.cwd(), 'src', 'test', 'generated', 'generators', 'react-typescript', 'app');
const answers = {
    appTitle: 'Amplicode Petclinic',
    appShortName: 'ampl-petclinic',
    graphqlUri: '/graphql',
    basePath: 'front'
};
describe('codegen app test', () => {
    it('should generate app', () => __awaiter(void 0, void 0, void 0, function* () {
        yield commons_1.cleanup(DEST_DIR);
        const codegenConfigPath = path_1.default.join(DEST_DIR, 'codegen.yml');
        const devEnvPath = path_1.default.join(DEST_DIR, '.env.development.local');
        const prodEnvPath = path_1.default.join(DEST_DIR, '.env.production.local');
        const manifestPath = path_1.default.join(DEST_DIR, 'public', 'manifest.json');
        // check that we remove previously generated app
        assert_1.default.ok(!fs_1.default.existsSync(codegenConfigPath));
        assert_1.default.ok(!fs_1.default.existsSync(devEnvPath));
        yield commons_1.generate(path_1.default.join(commons_1.GENERATORS_DIR, 'react-typescript', 'app'), commons_1.opts(DEST_DIR, answers, commons_1.SCHEMA_PATH));
        assert_1.default.ok(fs_1.default.existsSync(codegenConfigPath));
        assert_1.default.ok(fs_1.default.existsSync(devEnvPath));
        assert_1.default.ok(fs_1.default.existsSync(prodEnvPath));
        const doc = js_yaml_1.default.load(fs_1.default.readFileSync(codegenConfigPath, 'utf-8'));
        chai_1.expect(doc.schema).eq('../../../../fixtures/schema/schema.graphql');
        chai_1.expect(fs_1.default.readFileSync(devEnvPath, 'utf-8')).to.contain('REACT_APP_GRAPHQL_URI=/graphql');
        chai_1.expect(fs_1.default.readFileSync(prodEnvPath, 'utf-8')).to.contain('REACT_APP_GRAPHQL_URI=/graphql');
        chai_1.expect(fs_1.default.readFileSync(prodEnvPath, 'utf-8')).to.contain('PUBLIC_URL=/front/');
        const manifest = JSON.parse(fs_1.default.readFileSync(manifestPath, 'utf-8'));
        chai_1.expect(manifest['short_name']).to.eq('ampl-petclinic');
        chai_1.expect(manifest['name']).to.eq('Amplicode Petclinic');
    }));
});
//# sourceMappingURL=app.test.js.map