"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const menu_1 = require("../../../../generators/react-typescript/common/menu");
const uuid_1 = __importDefault(require("uuid"));
const chai_1 = require("chai");
const test_commons_1 = require("../../../test-commons");
describe('AppMenu generation', () => {
    describe('new menu item generation', () => {
        it('test getNewMenuItem', () => {
            const key = uuid_1.default.v4();
            const componentName = "TestComponent";
            const expectedMenuItem = `
    <MenuItem 
      screenId={"${componentName}"}
      icon={<BarsOutlined />}
      caption={"screen.${componentName}"}
      key={'${key}'}
    />`;
            chai_1.assert.equal(test_commons_1.stripNewLines(menu_1.getNewMenuItem(componentName, key)), test_commons_1.stripNewLines(expectedMenuItem));
        });
    });
    describe("update contentn in AppMenu", () => {
        describe("AppMenu with VerticalMenu", () => {
            it('adding new menu item to ROOT node', () => {
                const key = uuid_1.default.v4();
                const componentName = "TestComponent";
                const menuNode = "ROOT";
                const appMenuContent = `
        <VerticalMenu>
          <MenuItem/>
        </VerticalMenu>
        `;
                const expectedUpdatedMenuContent = `\r
        <VerticalMenu>\r
          <MenuItem/>\r
          <MenuItem \r
                screenId={"${componentName}"}\r
                icon={<BarsOutlined />}\r
                caption={"screen.${componentName}"}\r
                key={'${key}'}\r
              /></VerticalMenu>\r
        `;
                chai_1.assert.equal(test_commons_1.stripNewLines(menu_1.updateAppMenuContent(appMenuContent, componentName, menuNode, key)), test_commons_1.stripNewLines(expectedUpdatedMenuContent));
            });
            it('adding new menu item to custom node', () => {
                const key = uuid_1.default.v4();
                const componentName = "TestComponent";
                const menuNode = "test";
                const appMenuContent = `
        <VerticalMenu>
          <MenuItem/>
          <SubMenuItem
                key={"test"}
          >
            <MenuItem/>
          </SubMenuItem>
          <MenuItem/>
        </VerticalMenu>
        `;
                const expectedUpdatedMenuContent = `\r
        <VerticalMenu>\r
          <MenuItem/>\r
          <SubMenuItem\r
                key={"test"}\r
          >\r
            <MenuItem/>\r
            <MenuItem \r
                  screenId={"${componentName}"}\r
                  icon={<BarsOutlined />}\r
                  caption={"screen.${componentName}"}\r
                  key={'${key}'}\r
                /></SubMenuItem>\r
          <MenuItem/>\r
        </VerticalMenu>\r
        `;
                chai_1.assert.equal(test_commons_1.stripNewLines(menu_1.updateAppMenuContent(appMenuContent, componentName, menuNode, key)), test_commons_1.stripNewLines(expectedUpdatedMenuContent));
            });
            it("updating doesn't happen when menu node is null", () => {
                const key = uuid_1.default.v4();
                const componentName = "TestComponent";
                const appMenuContent = `
        <VerticalMenu>
          <MenuItem/>
          <SubMenuItem
                key={"test"}
          >
            <MenuItem/>
          </SubMenuItem>
          <MenuItem/>
        </VerticalMenu>
        `;
                chai_1.assert.equal(test_commons_1.stripNewLines(menu_1.updateAppMenuContent(appMenuContent, componentName, null, key)), test_commons_1.stripNewLines(appMenuContent));
            });
        });
        describe("AppMenu with HorizontalMenu", () => {
            it('adding new menu item to ROOT node', () => {
                const key = uuid_1.default.v4();
                const componentName = "TestComponent";
                const menuNode = "ROOT";
                const appMenuContent = `
        <HorizontalMenu>
          <MenuItem/>
        </HorizontalMenu>
        `;
                const expectedUpdatedMenuContent = `\r
        <HorizontalMenu>\r
          <MenuItem/>\r
          <MenuItem \r
                screenId={"${componentName}"}\r
                icon={<BarsOutlined />}\r
                caption={"screen.${componentName}"}\r
                key={'${key}'}\r
              /></HorizontalMenu>\r
        `;
                chai_1.assert.equal(test_commons_1.stripNewLines(menu_1.updateAppMenuContent(appMenuContent, componentName, menuNode, key)), test_commons_1.stripNewLines(expectedUpdatedMenuContent));
            });
            it('adding new menu item to custom node', () => {
                const key = uuid_1.default.v4();
                const componentName = "TestComponent";
                const menuNode = "test";
                const appMenuContent = `
        <HorizontalMenu>
          <MenuItem/>
          <SubMenuItem
                key={"test"}
          >
            <MenuItem/>
          </SubMenuItem>
          <MenuItem/>
        </HorizontalMenu>
        `;
                const expectedUpdatedMenuContent = `\r
        <HorizontalMenu>\r
          <MenuItem/>\r
          <SubMenuItem\r
                key={"test"}\r
          >\r
            <MenuItem/>\r
            <MenuItem \r
                  screenId={"${componentName}"}\r
                  icon={<BarsOutlined />}\r
                  caption={"screen.${componentName}"}\r
                  key={'${key}'}\r
                /></SubMenuItem>\r
          <MenuItem/>\r
        </HorizontalMenu>\r
        `;
                chai_1.assert.equal(test_commons_1.stripNewLines(menu_1.updateAppMenuContent(appMenuContent, componentName, menuNode, key)), test_commons_1.stripNewLines(expectedUpdatedMenuContent));
            });
            it("updating doesn't happen when menu node is null", () => {
                const key = uuid_1.default.v4();
                const componentName = "TestComponent";
                const appMenuContent = `
        <HorizontalMenu>
          <MenuItem/>
          <SubMenuItem
                key={"test"}
          >
            <MenuItem/>
          </SubMenuItem>
          <MenuItem/>
        </HorizontalMenu>
        `;
                chai_1.assert.equal(test_commons_1.stripNewLines(menu_1.updateAppMenuContent(appMenuContent, componentName, null, key)), test_commons_1.stripNewLines(appMenuContent));
            });
        });
    });
});
//# sourceMappingURL=menu.test.js.map