"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMockSchema = exports.stripNewLines = exports.assertFilesPlain = exports.assertFiles = exports.opts = exports.format = exports.assertContent = exports.createTestProjectEntityInfo = exports.modelCtx = void 0;
const assert_1 = __importDefault(require("assert"));
const model_utils_1 = require("../building-blocks/stages/writing/pieces/sdk/model/model-utils");
const fs_1 = __importDefault(require("fs"));
const prettier = require("prettier");
const path_1 = __importDefault(require("path"));
const assert_2 = require("assert");
const load_1 = require("@graphql-tools/load");
const enumsModel = require('./fixtures/enums-model.json');
const entityModel = require('./fixtures/entity-model.json');
function modelCtx() {
    return model_utils_1.collectModelContext({ entities: [entityModel], enums: enumsModel });
}
exports.modelCtx = modelCtx;
function createTestProjectEntityInfo(className, isBase = false) {
    const shortName = className.split('.').pop();
    return {
        type: { className: className },
        entity: { className: shortName, name: (isBase ? 'sys$' : 'mpg$') + shortName, fqn: className }
    };
}
exports.createTestProjectEntityInfo = createTestProjectEntityInfo;
function assertContent(actual, expect, multiline = true) {
    assert_1.default.strictEqual(drain(actual, multiline), drain(expect, multiline));
}
exports.assertContent = assertContent;
function drain(content, multiline = true) {
    const result = multiline
        ? content
            .replace(/^\s+/gm, '') //spaces at the line start, and empty lines
        : content
            .replace(/\n/g, ' '); //multiline false - join in one line
    return result
        .replace(/\s{2,}/g, ' ') //two or more spaces with one space
        .trim();
}
function format(file) {
    const formatted = prettier.format(fs_1.default.readFileSync(file, 'utf8'), { parser: "typescript" });
    fs_1.default.writeFileSync(file, formatted, 'utf8');
}
exports.format = format;
function opts(dir, answers, modelPath) {
    return {
        model: modelPath,
        dest: dir,
        debug: true,
        answers: Buffer.from(JSON.stringify(answers)).toString('base64')
    };
}
exports.opts = opts;
/**
 * @deprecated use assertFilesPlain, which is not change file content, it is not required since we are using prettier
 */
function assertFiles(filePath, clientDir, fixturesDir) {
    const actual = fs_1.default.readFileSync(path_1.default.join(clientDir, filePath), 'utf8');
    const expect = fs_1.default.readFileSync(path_1.default.join(fixturesDir, filePath), 'utf8');
    assertContent(actual, expect);
}
exports.assertFiles = assertFiles;
function assertFilesPlain(filePath, clientDir, fixturesDir) {
    const actual = fs_1.default.readFileSync(path_1.default.join(clientDir, filePath), 'utf8');
    const expect = fs_1.default.readFileSync(path_1.default.join(fixturesDir, filePath), 'utf8');
    assert_2.strictEqual(actual, expect);
}
exports.assertFilesPlain = assertFilesPlain;
/**
 * Test can fail when result and fixture contain different line separators (e.g. LF vs CRLF)
 *
 * @param str
 */
function stripNewLines(str) {
    return str.replace(/\r\n|\n/g, '');
}
exports.stripNewLines = stripNewLines;
function getMockSchema() {
    return __awaiter(this, void 0, void 0, function* () {
        const schemaPath = path_1.default.join(__dirname, '../../../../scripts/schema.graphql');
        const schemaString = fs_1.default.readFileSync(schemaPath, 'utf-8');
        return yield load_1.loadSchema(schemaString, { loaders: [] });
    });
}
exports.getMockSchema = getMockSchema;
//# sourceMappingURL=test-commons.js.map